@@ -12,9 +12,6 @@
 #include <QDir>
 #include <QString>
 
-#include "capalertinfo.h"
-#include "caparea.h"
-
 namespace KWeatherCore
 {
 
@@ -32,14 +29,9 @@ struct ResolvedWeatherDesc {
 class KWeatherCorePrivate
 {
 public:
-    static CAPPolygon stringToPolygon(const QString &str);
     static QString toFixedString(double num);
     static QDir getCacheDirectory(double latitude, double longitude);
 
-    static CAPAlertInfo::Urgency urgencyStringToEnum(const QString &str);
-    static CAPAlertInfo::Severity severityStringToEnum(const QString &str);
-    static CAPAlertInfo::Certainty certaintyStringToEnum(const QString &str);
-
     static int weatherIconPriorityRank(const QString &icon);
     static ResolvedWeatherDesc resolveAPIWeatherDesc(const QString &desc);
 };
